@@ -12,7 +12,8 @@ def main():
         raise Exception('missing worklet name to runner')
 
     gd = run_module('.'.join(target), run_name='__main__')
-    retval = marshal_for_perl(gd['c'] if 'c' in gd else gd['context'] if 'context' in gd else None)
+    context = gd['c'] if 'c' in gd else gd['context'] if 'context' in gd else None
+    retval = marshal_for_perl(context)
     print(retval)
 
 
