@@ -12,4 +12,7 @@ ND2_CONFIGURATION = json.loads(os.environ['ND2_CONFIGURATION'])
 
 
 def setting(name):
-    return ND2_CONFIGURATION[name]
+    if name in ND2_CONFIGURATION:
+        return ND2_CONFIGURATION[name]
+    else:
+        raise KeyError(f'unable to find setting "{name}" in Netdisco configuration')
